@@ -2,24 +2,27 @@ from __future__ import annotations
 
 from ctypes import (
     POINTER,
-    c_ssize_t,
+    Structure,
+    c_char,
+    c_uint8,
+    c_uint32,
     c_uint64,
     c_void_p,
     pythonapi,
-    c_char,
-    c_uint32,
-    c_uint8,
-    Structure,
 )
-from typing import TypeVar, Dict
+from typing import Dict, TypeVar
+
+from typing_extensions import Annotated
 
 from einspect.api import Py_ssize_t
 from einspect.protocols.delayed_bind import bind_api
 from einspect.structs.deco import struct
 from einspect.structs.py_object import PyObject
+from einspect.types import ptr
 
 __all__ = ("PyDictObject",)
 
+
 _KT = TypeVar("_KT")
 _VT = TypeVar("_VT")
 
@@ -52,10 +55,10 @@ class PyDictObject(PyObject[dict, _KT, _VT]):
     """
 
     # Number of items in the dictionary
-    ma_used: c_ssize_t
+    ma_used: int
     # Dictionary version: globally unique, changes on modification
-    ma_version_tag: c_uint64
-    ma_keys: POINTER(DictKeysObject)
+    ma_version_tag: Annotated[int, c_uint64]
+    ma_keys: ptr[DictKeysObject]
     # If ma_values is NULL, the table is "combined": keys and values
     # are stored in ma_keys. Otherwise, keys are stored in ma_keys
     # and values are stored in ma_values
@@ -95,4 +98,4 @@ class PyDictObject(PyObject[dict, _KT, _VT]):
     @classmethod
     def from_object(cls, obj: Dict[_KT, _VT]) -> PyDictObject[_KT, _VT]:
         """Create a PyDictObject from an object."""
-        return super(PyDictObject, cls).from_object(obj)  # type: ignore
+        return super().from_object(obj)  # type: ignore
