@@ -2,16 +2,19 @@
 from __future__ import annotations
 
 import ctypes
-from ctypes import Structure, pointer, py_object, pythonapi
-from typing import Dict, Generic, List, Tuple, Type, TypeVar, Union
+from ctypes import Structure, c_void_p, pythonapi
+from typing import TYPE_CHECKING, Dict, Generic, List, Tuple, Type, TypeVar, Union
 
-from typing_extensions import Self
+from typing_extensions import Annotated, Self
 
 from einspect.compat import Version, python_req
 from einspect.protocols.delayed_bind import bind_api
 from einspect.structs.deco import struct
 from einspect.types import ptr
 
+if TYPE_CHECKING:
+    from einspect.structs import PyTypeObject
+
 Fields = Dict[str, Union[str, Tuple[str, Type]]]
 
 _T = TypeVar("_T")
@@ -19,15 +22,13 @@ _KT = TypeVar("_KT")
 _VT = TypeVar("_VT")
 
 
-# noinspection PyPep8Naming
 @struct
 class PyObject(Structure, Generic[_T, _KT, _VT]):
     """Defines a base PyObject Structure."""
 
     ob_refcnt: int
-    ob_type: pointer[Self]
-    # Need to use generics from typing to work for py-3.8
-    _fields_: List[Tuple[str, type]]
+    ob_type: Annotated[ptr[PyTypeObject[Type[_T]]], c_void_p]
+    _fields_: List[Union[Tuple[str, type], Tuple[str, type, int]]]
     _from_type_name_: str
 
     @property
@@ -87,9 +88,10 @@ class PyObject(Structure, Generic[_T, _KT, _VT]):
         inst._from_type_name_ = type_repr
         return inst
 
-    def into_object(self) -> py_object[_T]:
+    def into_object(self) -> _T:
         """Cast the PyObject into a Python object."""
-        return ctypes.cast(self.as_ref(), ctypes.py_object)
+        py_obj = ctypes.cast(self.as_ref(), ctypes.py_object)
+        return py_obj.value
 
     def as_ref(self) -> ptr[Self]:
         """Return a pointer to the PyObject."""
